@@ -20,9 +20,12 @@
 #include <QPixmap>
 #include <QVBoxLayout>
 #include <QWidget>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QX11Info>
+#else
+#include <QtGui/private/qtx11extras_p.h>
+#endif
 
-#include "keyboard_config.h"
 #include "workspace_options.h"
 #include "keyboardmiscsettings.h"
 
@@ -331,7 +334,7 @@ void KCMKeyboardWidget::initializeLayoutsUI()
 
     connect(uiWidget->kdeKeySequence, &KKeySequenceWidget::keySequenceChanged, this, &KCMKeyboardWidget::alternativeShortcutChanged);
     connect(uiWidget->switchingPolicyButtonGroup, SIGNAL(buttonClicked(int)), this, SLOT(uiChanged()));
-    connect(uiWidget->switchingPolicyButtonGroup, qOverload<int>(&QButtonGroup::buttonClicked), this, &KCMKeyboardWidget::updateUiDefaultIndicator);
+    connect(uiWidget->switchingPolicyButtonGroup, &QButtonGroup::idClicked, this, &KCMKeyboardWidget::updateUiDefaultIndicator);
 
     connect(uiWidget->xkbGrpShortcutBtn, &QAbstractButton::clicked, this, &KCMKeyboardWidget::scrollToGroupShortcut);
     connect(uiWidget->xkb3rdLevelShortcutBtn, &QAbstractButton::clicked, this, &KCMKeyboardWidget::scrollTo3rdLevelShortcut);
@@ -631,7 +634,7 @@ void KCMKeyboardWidget::updateXkbShortcutButton(const QString &groupName, QPushB
 {
     QStringList grpOptions;
     if (uiWidget->kcfg_resetOldXkbOptions->isChecked()) {
-        QRegExp regexp = QRegExp("^" + groupName + Rules::XKB_OPTION_GROUP_SEPARATOR);
+        QRegularExpression regexp("^" + groupName + Rules::XKB_OPTION_GROUP_SEPARATOR);
         XkbOptionsTreeModel *model = dynamic_cast<XkbOptionsTreeModel *>(uiWidget->xkbOptionsTreeView->model());
         grpOptions = model->xkbOptions().filter(regexp);
     }
